@@ -30,14 +30,13 @@ pub unsafe extern "C" fn raw_finalize_unchecked<T>(
 ) {
   unsafe { Box::from_raw(finalize_data as *mut T) };
   if let Some((_, ref_val, finalize_callbacks_ptr)) =
-    REFERENCE_MAP.with(|reference_map| reference_map.borrow_mut().remove(&finalize_data))
+    REFERENCE_MAP.borrow_mut(|reference_map| reference_map.remove(&finalize_data))
   {
     let finalize_callbacks_rc = unsafe { Rc::from_raw(finalize_callbacks_ptr) };
 
     #[cfg(debug_assertions)]
     {
       let rc_strong_count = Rc::strong_count(&finalize_callbacks_rc);
-      let rc_weak_count = Rc::weak_count(&finalize_callbacks_rc);
       // If `Rc` strong count is 2, it means the finalize of referenced `Object` is called before the `fn drop` of the `Reference`
       // It always happened on exiting process
       // In general, the `fn drop` would happen first
@@ -46,11 +45,6 @@ pub unsafe extern "C" fn raw_finalize_unchecked<T>(
         "Rc strong count is: {}, it should be 1 or 2",
         rc_strong_count
       );
-      assert!(
-        rc_weak_count == 0,
-        "Rc weak count is: {}, it should be 0",
-        rc_weak_count
-      );
     }
     let finalize = unsafe { Box::from_raw(finalize_callbacks_rc.get()) };
     finalize();
